@@ -1,3 +1,23 @@
+/**********************************************************************
+This file is part of Exact.
+
+Copyright (c) 2022 Jo Devriendt
+
+Exact is free software: you can redistribute it and/or modify it under
+the terms of the GNU Affero General Public License version 3 as
+published by the Free Software Foundation.
+
+Exact is distributed in the hope that it will be useful, but WITHOUT
+ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public
+License version 3 for more details.
+
+You should have received a copy of the GNU Affero General Public
+License version 3 along with Exact. See the file used_licenses/COPYING
+or run with the flag --license=AGPLv3. If not, see
+<https://www.gnu.org/licenses/>.
+**********************************************************************/
+
 /**********************************************************************
 This file is part of the Exact program
 
@@ -162,6 +182,7 @@ struct ConstrExpSuper {
   virtual void sortInDecreasingCoefOrder(const std::function<bool(Var, Var)>& tiebreaker) = 0;
   virtual void sortWithCoefTiebreaker(const std::function<int(Var, Var)>& comp) = 0;
 
+  virtual void toStreamAsOPBlhs(std::ostream& o) const = 0;
   virtual void toStreamAsOPB(std::ostream& o) const = 0;
   virtual void toStreamWithAssignment(std::ostream& o, const IntMap<int>& level, const std::vector<int>& pos) const = 0;
 
@@ -377,6 +398,7 @@ struct ConstrExp final : public ConstrExpSuper {
   void sortInDecreasingCoefOrder(const std::function<bool(Var, Var)>& tiebreaker);
   void sortWithCoefTiebreaker(const std::function<int(Var, Var)>& comp);
 
+  void toStreamAsOPBlhs(std::ostream& o) const;
   void toStreamAsOPB(std::ostream& o) const;
   void toStreamWithAssignment(std::ostream& o, const IntMap<int>& level, const std::vector<int>& pos) const;
 
@@ -482,7 +504,10 @@ struct ConstrExp final : public ConstrExpSuper {
       reason->multiply(conflCoef);
       reason->weakenDivideRoundOrdered(reasonCoef, level);
     } else {
-      if (options.slackdiv) {
+      if (options.division.is("round-to-one")) {
+        reason->weakenDivideRoundOrdered(reasonCoef, level);
+        reason->multiply(conflCoef);
+      } else if (options.division.is("slackdiv")) {
         assert(reasonCoef / (reasonSlack + 1) < conflCoef);
         reason->weakenDivideRoundOrdered(reasonSlack + 1, level);
         reason->multiply(aux::ceildiv(conflCoef, reason->getCoef(asserting)));
@@ -509,7 +534,7 @@ struct ConstrExp final : public ConstrExpSuper {
     assert(reason->getCoef(asserting) >= conflCoef);
     assert(reason->getCoef(asserting) < 2 * conflCoef);
     assert(reason->getSlack(level) <= 0);
-    assert(options.slackdiv || conflCoef == reason->getCoef(asserting));
+    assert(options.division.is("slackdiv") || conflCoef == reason->getCoef(asserting));
 
     for (Var v : reason->vars) {
       Lit ll = reason->getLit(v);
